package urlsorting;

import java.net.*;
import java.io.*;
import java.util.ArrayList;
import java.util.StringTokenizer;
import java.util.logging.Level;
import java.util.logging.Logger;

public class Main {

    public static void main(String[] args) throws Exception {
        ArrayList<String> al = getWords("http://www.spiegel.de/");
        int length = 0;
        for (String s : al) {
            System.out.println(s);
            length += s.length();
        }
        double avGerman = (double) length / al.size();


        al = getWords("http://www.nytimes.com/");
        length = 0;
        for (String s : al) {
            System.out.println(s);
            length += s.length();
        }
        double avUS = (double) length / al.size();

        System.out.println("\n================================");
        System.out.println("Average German: "+avGerman+" || Average USA: "+avUS);
    }

    // -----------------------------------------------------------------
    // read words from URL
    public static ArrayList<String> getWords(String urlname) {
        ArrayList<String> al = new ArrayList<String>(5000);
        try {
            URL oracle = new URL(urlname);
            BufferedReader in = new BufferedReader(new InputStreamReader(oracle.openStream()));
            String inputLine;
            while ((inputLine = in.readLine()) != null) {
                StringTokenizer st = new StringTokenizer(inputLine);
                while (st.hasMoreTokens()) {
                    String s = (String) st.nextElement();
                    String s1 = filterWord(s);
                    if (s1 != null) {
                        al.add(s1);
                    }
                }
            }
            in.close();
        } catch (Exception ex) {
            Logger.getLogger(Main.class.getName()).log(Level.SEVERE, null, ex);
        }
        return (al);
    }

    //---------------------------------------------------------------
    // filterWord
    // returns lower case, trimmed version of input word if the input
    // consists of valid characters.
    // returns null otherwise.
    private static String filterWord(String s) {
        s = s.toLowerCase();
        // filter sentence ends
        if (s.endsWith(".") || s.endsWith("!") || s.endsWith(",") || s.endsWith("?") || s.endsWith(";")) {
            s = s.substring(0, s.length() - 1);
        }

        // words have to consist of characters a-z only (plus the german Umlaute)
        boolean isWord = true;
        for (int i = 0; i < s.length(); i++) {
            int b = (int) s.charAt(i);

            if (b < 97 || b > 122) {
                if (b != 132 && b != 148 && b != 129) {
                    isWord = false;
                    break;
                }
            }
        }
        if (isWord) {
            return (s);
        } else {
            return (null);
        }
    }
}
